#include <iostream>
#include "MyWorld.h"
#include "Ball.h"
#include "Spring.h"
#include "CVector.h"
#include "FixedHook.h"

using namespace std;

int main(int argvc, char * argv[]) {
      if (argvc != 4)  {
        cout << "usage: "<< argv[0] << " <delta_time[s]> <end_time[s]> <sampling_time[s]>" << endl;
        exit(-1);
      }
      double deltaTime = atof(argv[1]);    // [s]
      double endTime = atof(argv[2]);      // [s]
      double samplingTime = atof(argv[3]); // [s]
      MyWorld world(cout);
      
      double mass = 1.0;      // 1 [kg] 
      double radius = 0.1;    // 10 [cm] 
      CVector position(1,0);  // 1 [m] 
      CVector speed(0,0.5);     // 0.5 [m/s]
      Ball b0(mass, radius, position, speed);
      position.set(1,0.8);
      speed.set(0,0);     
      Ball b1(mass, radius, position, speed);
      position.set(0,0);
      FixedHook hook0(position);
      position.set(2,0);
      FixedHook hook1(position);
      Spring spring0(0.8, 0.5);      
      spring0.attachEnd(&hook0);
      spring0.attachEnd(&b1);
      Spring spring1(0.8, 0.5);      
      spring1.attachEnd(&hook1);
      spring1.attachEnd(&b1);
      world.addElement(&hook0);
      world.addElement(&spring0);
      world.addElement(&b1);
      world.addElement(&spring1);
      world.addElement(&hook1);
      world.addElement(&b0);
      world.simulate(deltaTime, endTime, samplingTime); // delta time[s], total simulation time [s].
}
